# Video-compress

[![](https://img.shields.io/pypi/v/video-compress.svg)](https://pypi.org/project/video-compress)
[![](https://github.com/jiacai2050/video-compress/actions/workflows/ci.yml/badge.svg)](https://github.com/jiacai2050/video-compress/actions/workflows/ci.yml)

Inspired by <https://x.com/mortenjust/status/1818027566932136062>

# Usage

First install the [ffmpeg](https://www.ffmpeg.org/download.html), then

``` bash
pip install video-compress
```

This will install two commands: `vc`{.verbatim},
`video-compress`{.verbatim}, which are identical.
